import requests


def youdao_API(word, key, fromkey, doctype='json'):
    if doctype not in "xml json jsonp".split():
        raise Exception("Doctype Error")
    url = "http://fanyi.youdao.com/openapi.do?keyfrom={0}&key={1}&type=data&doctype={2}&version=1.1&q={3}"
    url = url.format(fromkey, key, doctype, word)

    try:
        response = requests.get(url).json()
    except Exception as e:
        raise e

    return response


def tword(word):
    key = '1415423309'
    fromkey = 'steamrep'
    doctype = 'json'

    response = youdao_API(word, key, fromkey, doctype)

    if 'translation' in response.keys():
        print (''.join(response['translation']))
    else:
        print ("No explain")




from setuptools import setup, find_packages

setup(
    name="translateit",
    version='0.0.2',
    author="KIDJourney",
    author_email="kingdeadfish@qq.com",
    description="This is a simple console translator",
    license="MIT",
    keywords="hello world translate requests",
    
    packages=find_packages('src'),
    package_dir={'': 'src'},

    zip_safe=False,

    install_requires=[
            'requests',
    ],


    classifiers=[
        'Programming Language :: Python :: 3.4',
    ],


    entry_points={
        'console_scripts': [
            'translate = translate.__main__:main'
        ]
    },
)
